sourcepoint_unified_cmp library

Classes

AbstractSourcepointConsentController
An abstract class representing a Sourcepoint consent controller.
CCPAConsent
Represents the CCPA (California Consumer Privacy Act) consent.
ConsentAction
Represents a consent action. The ConsentAction contains ConsentAction |-- actionType: ActionType |-- pubData: JSONObject |-- campaignType: CampaignType |-- customActionId: String?
ConsentChangeNotifier
A class that extends ChangeNotifier and provides a way to notify listeners when the consent changes. This is triggered by the platform implementation when the consent is ready.
ConsentStatus
represents the detailed consent status
GDPRConsent
Represents the GDPR consent.
GDPRPurposeGrants
Represents the GDPR purpose grants.
GranularStatus
Represents the granular status of a component.
SourcepointController
A controller for managing Sourcepoint functionality.
SourcepointEventDelegate
A delegate class for handling Sourcepoint events. This class implements the SourcepointEventDelegatePlatform interface.
SourcepointEventDelegatePlatform
Represents the platform interface for handling Sourcepoint event delegates. This abstract class defines the contract for implementing Sourcepoint event delegates on different platforms.
SourcepointUnifiedCMPBuilder
A builder class for creating a FutureBuilder that returns an SPConsent object.
SourcepointUnifiedCmpPlatform
The interface that implementations of sourcepoint_unified_cmp must implement.
SPConfig
Represents the configuration for Sourcepoint Unified CMP. Use the factory method to obtain a lazy configuration for v6 (Unified SDK). This contains your organization's account information and includes the type of campaigns that will be run on this property. This object will be instantiated at the first usage of the CMP SDK. The config object is a simple DTO.
SPConsent
The SpConsent object contains all the info related with the user consent action.
SPError
Represents an error that can occur in the Sourcepoint Unified CMP platform interface.

Enums

ActionType
Action emitted by the privacy manager
CampaignsEnv
Sourcepoint campaign environment.
CampaignType
Consent categories.
GranularState
MessageLanguage
Represents the language used in the privacy manager.
MessageType
message type - android only
PMTab
Selected tab within the privacy manager.

Functions

generatePreloadJSString(SPConsent consent) String
Generates a JavaScript string to preload consent data into a web view.