SourcepointEventDelegatePlatform class abstract

Represents the platform interface for handling Sourcepoint event delegates. This abstract class defines the contract for implementing Sourcepoint event delegates on different platforms.

Implementers

Constructors

SourcepointEventDelegatePlatform({void onConsentReady(SPConsent)?, void onUIFinished()?, void onUIReady()?, void onError(SPError error)?, void onAction(ConsentAction consentAction)?, void onNoIntentActivitiesFound(String url)?, void onSpFinished(SPConsent)?})
Represents a platform-specific delegate for handling Sourcepoint events. This delegate is responsible for handling events related to the Sourcepoint Unified CMP platform interface.

Properties

hashCode int
The hash code for this object.
no setterinherited
onAction → void Function(ConsentAction consentAction)?
Callback function that is called when an action occurs.
final
onConsentReady → void Function(SPConsent)?
A callback function that is called when the consent is ready.
final
onError → void Function(SPError error)?
Callback function that is called when an error occurs.
final
onNoIntentActivitiesFound → void Function(String url)?
Callback function that is called when no intent activities are found.
final
onSpFinished → void Function(SPConsent)?
Callback function that is called when the Sourcepoint Unified CMP
final
onUIFinished → void Function()?
Callback function that is called when the UI is finished.
final
onUIReady → void Function()?
Callback function that is called when the UI is ready.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited