SourcepointUnifiedCMPBuilder class
A builder class for creating a FutureBuilder that returns an SPConsent object.
This class extends the FutureBuilder class and is used to build a widget that asynchronously retrieves and displays consent information from Sourcepoint Unified CMP. The FutureBuilder is responsible for handling the state of the asynchronous operation and updating the UI accordingly.
Example usage:
SourcepointUnifiedCMPBuilder(
controller: _controller,
builder: (BuildContext context, AsyncSnapshot<SPConsent> snapshot) {
if (snapshot.hasData) {
return Text('Consent: ${snapshot.data}');
} else if (snapshot.hasError) {
return Text('Error: ${snapshot.error}');
} else {
return CircularProgressIndicator();
}
},
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FutureBuilder<
SPConsent> - SourcepointUnifiedCMPBuilder
Constructors
-
SourcepointUnifiedCMPBuilder({required AsyncWidgetBuilder<
SPConsent> builder, required AbstractSourcepointConsentController controller, Key? key}) - A builder class for creating instances of SourcepointUnifiedCMP.
Properties
-
builder
→ AsyncWidgetBuilder<
SPConsent> -
The build strategy currently used by this builder.
finalinherited
-
future
→ Future<
SPConsent> ? -
The asynchronous computation to which this builder is currently connected,
possibly null.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialData → SPConsent?
-
The data that will be used to create the snapshots provided until a
non-null future has completed.
finalinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FutureBuilder< SPConsent> > -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited